Learn R Programming

wtcrsk (version 1.6)

crr.wt.KM: Regression modeling of subdistribution functions using Kaplan-Meier weight.

Description

Fits a subdistribution hazards regression model using the Kaplan-Meier weight. This is the same model as Fine and Gray (1999).

Usage

crr.wt.KM(t, ic, z, variance, var.conservative)

Arguments

t
a vector of observed times.
ic
a vector of cause indicators.
z
a matrix of covariates for fitting the model.
variance
Includes variance calculation if TRUE, Skips variance calculation if FALSE.
var.conservative
Includes minor term of variance of beta if FALSE, no minor term for variance of beta if TRUE.

Value

Details

More details are given in the reference.

References

He P, Scheike TH and Zhang MJ, A proportional hazards regression model for the subdistribution with covariates adjusted censoring weight for competing risks data, Technical Report #61, Division of Biostatistics, Medical College of Wisconsin, November 2013.

Fine JP and Gray RJ (1999), A proportional hazards model for the subdistribution of a competing risk. Journal of The American Statistical Association 94, 496-509.