crr.wt.KM.str:
Regression modeling of subdistribution functions using the stratified Kaplan-Meier weight.
Description
Fits a subdistribution hazards regression model using the stratified Kaplan-Meier adjusted weight. Use predicted censoring probability based on the stratified Kaplan-Meier estimate for each individual.