Learn R Programming

wtcrsk (version 1.6)

wtcrsk-package: Competing isks regression models with covariate-adjusted censoring weights

Description

Estimation and regression modeling of subdistribution functions for competing risks data with adjustment for covariate-dependent censoring, as described in He et al. (2015).

Arguments

Details

Package:
wtcrsk
Type:
Package
Version:
1.6
Date:
2015-12-03
License:
GPL >= 2

References

He P, Eriksson F, Scheike TH and Zhang MJ, A proportional hazards regression model for the subdistribution with covariates adjusted censoring weight for competing risks data, Scandinavian Journal of Statistics (2015), Article first published online.