crr.wt.COX:
Regression modeling of subdistribution function using the Cox weight.
Description
Fits a subdistribution hazards regression model using the Cox model adjusted weight. Use predicted censoring probability based on the Cox model for each individual.
a matrix of associated covariates for fitting the censoring distribution.
variance
Includes variance calculation if TRUE, Skips variance calculation if FALSE.
var.conservative
Includes minor term of variance of beta if FALSE, no minor term for variance of beta if TRUE.
Value
Details
More details are given in the reference.
References
He P, Scheike TH and Zhang MJ, A proportional hazards regression model for the subdistribution with covariates adjusted censoring weight for competing risks data, Technical Report #61, Division of Biostatistics, Medical College of Wisconsin, November 2013.