predict.crrwt:
Compute predictive CIFs for given set of covariates.
Description
This is a function to calculate prediction of the cumulative incidence function (CIF) as well as its variance at observed failure times given in original data.
Usage
"predict"(object, z, ...)
Arguments
object
a 'crrwt' class object obtained from crr.wt function.
z
sets of covariates used for prediction, each row represents a new set of covariates.
...
additional arguments affecting the predictions produced.
Value
z
given sets of covariates.
time
observed failure times.
F1
predicted cumulative incidence probabilities at observed failure times.
F1sd
standard errors of predicted cumulative incidence probabilities.
Details
More derivations are given in the reference.
References
He P, Scheike TH and Zhang MJ, A proportional hazards regression model for the subdistribution with covariates adjusted censoring weight for competing risks data, Technical Report #61, Division of Biostatistics, Medical College of Wisconsin, November 2013.